#!/bin/bash

# $1: JQ key identifier, e.g. .keyName
# $2: Path to file
function read_config() {
    eval $(yq -r $1' | to_entries[] | "export \(.key)=\(.value)"' $2)
}

# $1: Prefix for directory deletion
function delete_old_versions() {
    # Get all URLs for all prefixes in directory
    # Assumes that pagination isn't needed.
    urls=$(gcloud storage ls gs://$1/${workload_name} --json \
        | jq -r '.[] | select(.type == "prefix") | .url')

    # Create an array of JSONs mapping URL to timestamp
    url_ts=""
    for url in $urls; do
        ts=$(gcloud storage ls $url --json \
            | jq -r '[.[] | select(.type == "cloud_object")][0] | .metadata.timeCreated')
        url_ts="${url_ts} {\"url\": \"$url\", \"ts\": \"$ts\"}"
    done

    # Delete any "folders" that are outside the desired range to retain
    delete_dirs=$(echo "${url_ts}" \
        | jq -rs 'sort_by(.ts) | reverse | .['${num_versions}':] | .[].url')
    if [ -z "$delete_dirs" ]; then
        echo "Fewer than ${num_versions} versions detected for ${workload_name}. No data to delete!"
    else
        echo "Found more than ${num_versions} versions for ${workload_name}."
        for d in $delete_dirs; do
            echo "Deleting the following directory: $d"
            gcloud storage rm $d**
        done
    fi;
}
